@@ -18,6 +18,7 @@ class UdpSession(object):
     s = None
     buffer_arr = []
     thread_lock = threading.Lock()
+    socket_lock = threading.Lock()
     read_timeout = 5
 
     @classmethod
@@ -27,26 +28,37 @@ class UdpSession(object):
         home = 'WHATAP_HOME'
         whatap_home = os.environ.get(home,'')
         unix_socket_path = os.path.join(whatap_home, conf.unix_socket)
+        
         if conf.unix_socket_enabled and os.path.exists(unix_socket_path):
-            with cls.thread_lock:
-                if not cls.s:
-                    tmp_socket_path = os.path.join('/tmp', 'whatap.{}.sock'.format(os.getpid()))
-                    if os.path.exists(tmp_socket_path):
-                        os.remove(tmp_socket_path)
-                    
-                    sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
-                    sock.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, PacketEnum.PACKET_SEND_BUFFER_SIZE)
-                    sock.bind(tmp_socket_path)
-                    sock.connect(unix_socket_path)
-                    sock.settimeout(cls.read_timeout)
-                    cls.s = sock
+            with cls.socket_lock:
+                tmp_socket_path = os.path.join('/tmp/whatap', 'whatap.{}.sock'.format(os.getpid()))
+                if os.path.exists(tmp_socket_path):
+                    os.remove(tmp_socket_path)
+                prefix=os.path.split(tmp_socket_path)[0]
+                if not os.path.exists(prefix):
+                    os.makedirs(prefix)
+                sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
+                sock.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, PacketEnum.PACKET_SEND_BUFFER_SIZE)
+                sock.bind(tmp_socket_path)
+                sock.connect(unix_socket_path)
+                sock.settimeout(cls.read_timeout)
+                if cls.s:
+                    try:
+                        cls.s.close()
+                    except Exception as e:
+                        print(e)
+                cls.s = sock
         else:
             sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, PacketEnum.PACKET_SEND_BUFFER_SIZE)
             sock.connect((PacketEnum.SERVER, PacketEnum.PORT))
-            cls.s = sock
             sock.settimeout(cls.read_timeout)
-
+            if cls.s:
+                try:
+                    cls.s.close()
+                except Exception as e:
+                    print(e)
+            cls.s = sock
         return cls.s
 
     @classmethod
