@@ -8,6 +8,7 @@ from whatap.net.udp_session import UdpSession
 from whatap.trace.trace_context import TraceContext
 from whatap.trace.trace_context_manager import TraceContextManager
 from whatap.util.date_util import DateUtil
+from whatap.util.hash_util import HashUtil
 from whatap.util.userid_util import UseridUtil as userid_util
 from functools import wraps
 from whatap import logging
@@ -75,6 +76,9 @@ def start_interceptor(ctx):
     
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
+
+    if ctx.service_name and not ctx.service_hash:
+        ctx.service_hash = HashUtil.hashFromString(ctx.service_name)
     
     datas = [ctx.host,
              ctx.service_name,
@@ -106,7 +110,7 @@ def end_interceptor(thread_id=None, ctx= None):
     ctx.start_time = start_time
 
     datas = [ctx.host, ctx.service_name, ctx.mtid, ctx.mdepth, ctx.mcaller_txid,
-             ctx.mcaller_pcode, ctx.mcaller_spec, ctx.mcaller_url, ctx.mcaller_poid]
+             ctx.mcaller_pcode, ctx.mcaller_spec, str(ctx.mcaller_url_hash), ctx.mcaller_poid]
     ctx.elapsed = DateUtil.nowSystem() - start_time
 
     UdpSession.send_packet(PacketTypeEnum.TX_END, ctx, datas)
